@@ -1,4 +1,4 @@
-#   Copyright (C) 1987-2004 by Jeffery P. Hansen
+#   Copyright (C) 1987-2005 by Jeffery P. Hansen
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 #   along with this program; if not, write to the Free Software
 #   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 #
-# Last edit by hansen on Tue Jun  8 13:28:42 2004
+# Last edit by hansen on Thu Sep  2 11:07:49 2004
 #
 
 set blk_src ""
@@ -178,11 +178,74 @@ proc tkg_blockListSetLibFlag {name islib} {
   }
 }
 
-proc tkg_makeBlockList {w} {
-#  frame $w -relief groove -bd 2
-#  frame $w.f
-#  label $w.f.lab -text [m iblmodule]:
+namespace eval BlockListDrag {
+  variable drag_obj ""
+  variable mouseset_x 0
+  variable mouseset_y 0
 
+  proc seeB1 {w x y} {
+    variable mouseset_x
+    variable mouseset_y
+    variable drag_obj
+
+    set mouseset_x ""
+    set mouseset_y ""
+    set drag_obj ""
+  }
+
+  proc seeModuleDrop {m w x y} {
+    variable mouseset_x
+    variable mouseset_y
+
+    set mouseset_x ""
+    set mouseset_y ""
+
+    if { $w == ".frame.cf.canvas"} {
+      action Make "gat_make block -func $m -x $x -y $y -interface 1"
+    }
+  }
+
+  #
+  # Respond to motion of the mouse with button 1 depressed
+  #
+  proc seeMotion {w x y} {
+    variable drag_obj
+    variable mouseset_x
+    variable mouseset_y
+    global bd
+
+    if { $mouseset_x == "" } {
+      set mouseset_x $x
+      set mouseset_y $y
+      set i [$w curselection]
+      if { $i != "" } {
+	set drag_obj [$w get $i]
+      } else {
+	set drag_obj ""
+      }
+      return
+    }
+
+
+    if { $drag_obj != "" } {
+      set dx [expr $mouseset_x - $x]
+      set dy [expr $mouseset_y - $y]
+      if { [expr $dx*$dx + $dy*$dy] > 25 } {
+	set lbl [string trim $drag_obj "+@()"]
+
+	set dw [Dragger::make -command "BlockListDrag::seeModuleDrop $lbl"]
+	if {$dw != "" } {
+	  label $dw.icon -image [gifI "$bd/module.gif"]
+	  label $dw.label -text $lbl
+	  pack $dw.icon $dw.label -padx 2 -pady 2 -side left
+	}
+      }
+    }
+  }
+}
+
+
+proc tkg_makeBlockList {w} {
   labelframe $w [m iblmodule]
   frame $w.pad
   pack $w.pad -pady 3
@@ -197,7 +260,8 @@ proc tkg_makeBlockList {w} {
 
   set cmd { continueAction GotoBlock { gat_openBox [string trim [.sbar.blklst.f.list get [.sbar.blklst.f.list curselection]] "+()"]} }
   bind $w.f.list <Double-ButtonRelease-1> $cmd
-  bind $w.f.list <ButtonPress> { action -Unselect { tkg_undoSelections blocks } }
+  bind $w.f.list <ButtonPress> { action -Unselect { tkg_undoSelections blocks };  BlockListDrag::seeB1 %W %X %Y }
+  bind $w.f.list <B1-Motion> { BlockListDrag::seeMotion %W %X %Y }
 
 #    helpon $w.f.lab [m ho.f.modlist]
   helpon ${w}_label [m ho.f.modlist]
