@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -355,6 +355,15 @@ void SGate_addPort(SGate *g,const char *pname,SNet *N,int comp)
     pname = g->g_type->gi_pad[i].name;
   }
   SPortList_add(&g->g_ports,new_SPort(pname,N,comp));
+
+#if 0
+#define XXX(p) ((p) ? (p)->p_net->n_name : "-")
+  sendMsg("echo ATTACH(%p) Z=%s  I=%s  G=%s\n",g,
+	  XXX(g->g_ports.port[0]),
+	  XXX(g->g_ports.port[1]),
+	  XXX(g->g_ports.port[2]));
+#endif
+
 }
 
 static SGateInfo *gpc_type = 0;
