@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -861,6 +861,92 @@ int SState_isLogic(SState *S)
   return 1;
 }
 
+/*
+ * Shift I and place the result in R.
+ *
+ * Arguments:
+ *
+ *    R		Return value from operation
+ *    I		Value to be shifted
+ *    n		Bits to shift (>0 for left shift, <0 for right shift)
+ *    in1	Shift-in value to use in 'one' field
+ *    in0	Shift-in value to use in 'zero' field
+ *    inZ	Shift-in value to use in 'flt' field
+ */
+void SState_roll(SState *R,SState *I,int n)
+{
+  int bits = R->nbits;
+  unsigned mask = (bits<32) ? ((1<<bits)-1) : ~0;
+
+  if (n < 0)
+    n += bits;
+
+  assert(I->nbits <= 32);
+  assert(n >= 0);
+
+  if (n > 0) {
+    unsigned emask = (n<32) ? ((1<<n)-1) : ~0;
+
+    R->one[0] = (I->one[0] << n) | ((I->one[0] >> (bits-n)) & emask);
+    R->zero[0] = (I->zero[0] << n) | ((I->zero[0] >> (bits-n)) & emask);
+    R->flt[0] = (I->flt[0] << n) | ((I->flt[0] >> (bits-n)) & emask);
+  } else {
+    R->one[0] = I->one[0];
+    R->zero[0] = I->zero[0];
+    R->flt[0] = I->flt[0];
+  }
+
+  R->one[0] &= mask;
+  R->zero[0] &= mask;
+  R->flt[0] &= mask;
+}
+
+
+/*
+ * Shift I and place the result in R.
+ *
+ * Arguments:
+ *
+ *    R		Return value from operation
+ *    I		Value to be shifted
+ *    n		Bits to shift (>0 for left shift, <0 for right shift)
+ *    in1	Shift-in value to use in 'one' field
+ *    in0	Shift-in value to use in 'zero' field
+ *    inZ	Shift-in value to use in 'flt' field
+ */
+void SState_shift(SState *R,SState *I,int n,int in1,int in0,int inZ)
+{
+  int bits = R->nbits;
+  unsigned mask = (bits<32) ? ((1<<bits)-1) : ~0;
+
+  assert(I->nbits <= 32);
+
+  if (n > 0) {
+    unsigned emask = (n<32) ? ((1<<n)-1) : ~0;
+
+    R->one[0] = (I->one[0] << n) | (in1*emask);
+    R->zero[0] = (I->zero[0] << n) | (in0*emask);
+    R->flt[0] = (I->flt[0] << n) | (inZ*emask);
+  } else if (n < 0) {
+    unsigned emask;
+
+    n = -n;
+    emask = ((n<32) ? ((1<<n)-1) : ~0) << (bits-n);
+
+    R->one[0] = (I->one[0] >> n) | (in1*emask);
+    R->zero[0] = (I->zero[0] >> n) | (in0*emask);
+    R->flt[0] = (I->flt[0] >> n) | (inZ*emask);
+  } else {
+    R->one[0] = I->one[0];
+    R->zero[0] = I->zero[0];
+    R->flt[0] = I->flt[0];
+  }
+
+  R->one[0] &= mask;
+  R->zero[0] &= mask;
+  R->flt[0] &= mask;
+}
+
 int testLogic(char *command)
 {
   char buf1[STRMAX],buf2[STRMAX];
