@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -533,6 +533,16 @@ void EvQueue_setPort(EvQueue *Q,SPort *P,SState *xS,simTime delay)
   SState_copy(S,xS);
   if (P->p_comp) SState_not(S,S);
 
+#if 0
+  {
+    char Sbuf[STRMAX],Pbuf[STRMAX];
+
+    SState_getstr(S,Sbuf);
+    SState_getstr(&P->p_qstate,Pbuf);
+    sendMsg("echo SState_eq(%s, %s) = %d",Sbuf,Pbuf,SState_eq(S,&P->p_qstate));
+  }
+#endif
+
   /* No need to set port */
   if (SState_eq(S,&P->p_qstate)) {
     free_SState(S);
