@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Wed May 26 12:46:23 2004
+    Last edit by hansen on Thu Sep  2 11:04:53 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <string.h>
@@ -218,7 +218,7 @@ GCElement *Block_Make(EditState **es,GModuleDef *env,int GType,
 		      int x,int y,int r,const char *Name,int noWire,const char **options,int nOptions)
 {
   GCElement *g,*copy;
-  const char *Func,*Size;
+  const char *Func,*Size,*Interf;
   int W,H;
 
   if (!(g = Generic_Make(es,env,GType,x,y,r,Name,noWire,options,nOptions)))
@@ -226,6 +226,7 @@ GCElement *Block_Make(EditState **es,GModuleDef *env,int GType,
 
   Func = seekOption("-func",options,nOptions);
   Size = seekOption("-size",options,nOptions);
+  Interf = seekOption("-interface",options,nOptions);
 
   ob_touch(g);
   
@@ -239,6 +240,21 @@ GCElement *Block_Make(EditState **es,GModuleDef *env,int GType,
   
   if (Func) {
     g->u.block.BlockFunction = ob_strdup(Func);
+
+    if (Interf && *Interf == '1') {
+      if ((copy = env_blockdescript(g))) {
+	g->u.block.gwidth = copy->u.block.gwidth;
+	g->u.block.gheight = copy->u.block.gheight;
+      }
+
+      g->xpos -= g->u.block.gwidth/2;
+      g->ypos -= g->u.block.gheight/2;
+
+      if (copy) {
+	block_replicatewires(g,copy,(*es)->env);
+      }
+    }
+
   } else if (es) {
     GGateInfo *gi = g->typeinfo;
     int ok;
