@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Wed Jun  9 14:07:20 2004
+    Last edit by hansen on Fri Sep  3 14:09:35 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <string.h>
@@ -205,7 +205,7 @@ static void Comment_updateSize(GCElement *g)
 #if USE_ICONV
     {
       char buf[STRMAX];
-      DoTcl("iconv decode \"%s\"",quoteChars(buf,comment_emptymsg,"\"\\"));
+      DoTcl("iconv decode \"%s\"",quoteChars(buf,comment_emptymsg,"\"\\[]"));
       comment_emptymsg = XGate.tcl->result;
     }
 #endif
@@ -408,7 +408,7 @@ void Comment_Draw(GCElement *g,int md)
 #if USE_ICONV
     {
       char buf[STRMAX];
-      DoTcl("iconv decode \"%s\"",quoteChars(buf,comment_emptymsg,"\"\\"));
+      DoTcl("iconv decode \"%s\"",quoteChars(buf,comment_emptymsg,"\"\\[]"));
       comment_emptymsg = XGate.tcl->result;
     }
 #endif
