@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Mon Jan 26 09:17:28 2004
+    Last edit by hansen on Fri Sep  3 14:00:19 2004
 ****************************************************************************/
 #include "tkgate.h"
 
@@ -461,11 +461,6 @@ void led_PSdrawname(FILE *f,GCElement *g,char *ename,int ax,int ay,int w,int h)
 {
   int x,y;
 
-  if (g->selected)
-    XSetFont(XGate.D,XGate.instGC,XGate.textbXF);
-  else
-    XSetFont(XGate.D,XGate.instGC,XGate.textXF);
-
   x = ax+w/2;
 
   if (g->orient == 2) {
