@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Tue Jun  8 11:54:02 2004
+    Last edit by hansen on Fri Sep  3 14:03:25 2004
 ****************************************************************************/
 /*
     Postscript generator for tkgate.
@@ -89,7 +89,7 @@ char *gateprolog[] = {
 
 char *gateps_copyright[] = {
   "%",
-  "% Copyright (C) 1987-2004 by Jeffery P. Hansen",
+  "% Copyright (C) 1987-2005 by Jeffery P. Hansen",
   "%    This program (the Postscript Prolog) is free software; you can redistribute",
   "%    it and/or modify it under the terms of the GNU General Public License",
   "%    as published by the Free Software Foundation; either version 2 of the",
@@ -703,6 +703,7 @@ static void GPrint_pageSetup(GPrint *P)
   fprintf(P->p_f,"%%%%IncludeResource: font Symbol\n");
 
   if (!P->p_isepsf) {
+#if TKGATE_PSPAGESIZING
     fprintf(P->p_f,"%%%%BeginFeature: *PageSize %s\n",tray);
     fprintf(P->p_f,"statusdict /%s known {\n",tray);
     fprintf(P->p_f,"  statusdict begin\n");
@@ -710,14 +711,16 @@ static void GPrint_pageSetup(GPrint *P)
     fprintf(P->p_f,"  end\n");
     fprintf(P->p_f,"} if\n");
     fprintf(P->p_f,"%%%%EndFeature\n");
-
-    fprintf(P->p_f,"%%%%BeginFeature: *DuplexMode %s\n",dup_mode);
-    fprintf(P->p_f,"statusdict /setduplexmode known {\n");
-    fprintf(P->p_f,"  statusdict begin\n");
-    fprintf(P->p_f,"    %s setduplexmode\n",dup_mode);
-    fprintf(P->p_f,"  end\n");
-    fprintf(P->p_f,"} if\n");
-    fprintf(P->p_f,"%%%%EndFeature\n");
+#endif
+    if (dup_mode) {
+      fprintf(P->p_f,"%%%%BeginFeature: *DuplexMode %s\n",dup_mode);
+      fprintf(P->p_f,"statusdict /setduplexmode known {\n");
+      fprintf(P->p_f,"  statusdict begin\n");
+      fprintf(P->p_f,"    %s setduplexmode\n",dup_mode);
+      fprintf(P->p_f,"  end\n");
+      fprintf(P->p_f,"} if\n");
+      fprintf(P->p_f,"%%%%EndFeature\n");
+    }
   }
 
   fprintf(P->p_f,"%%%%EndSetup\n");
@@ -1278,7 +1281,7 @@ static HGNode *build_HGNodeGraph(GModuleDef *M,NHash *H)
 	GModuleDef *CM = env_findModule(g->u.block.BlockFunction);
 	HGNode *CG;
 
-	if (!NHash_find(LH,(nkey_t)CM)) {
+	if (CM && !NHash_find(LH,(nkey_t)CM)) {
 	  NHash_insert(LH,(nkey_t)CM,CM);
 	  CG = build_HGNodeGraph(CM,H);
 	  HGNode_addChild(G,CG);
