@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Tue Jun  8 13:09:56 2004
+    Last edit by hansen on Thu Sep  2 11:11:30 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -240,6 +240,7 @@ int gat_make(ClientData _d,Tcl_Interp *tcl,int argc,const char *argv[])
   struct gateinfo *GI;
   int x,y,r;
   struct celemnt *g;
+  const char *xstr,*ystr;
 
   assert(argc >=  2);
 
@@ -247,7 +248,17 @@ int gat_make(ClientData _d,Tcl_Interp *tcl,int argc,const char *argv[])
 
   if (!modifyOK(es,0)) return TCL_OK;
 
-  if (XGate.ed->mark_vis) {
+  xstr = seekOption("-x",argv,argc);
+  ystr = seekOption("-y",argv,argc);
+
+  if (xstr && ystr) {
+    sscanf(xstr,"%d",&x);
+    sscanf(ystr,"%d",&y);
+    x /= XGate.circuit->zoom_factor;
+    y /= XGate.circuit->zoom_factor;
+    x = wtoc_x(x);
+    y = wtoc_y(y);
+  } else if (XGate.ed->mark_vis) {
     x = XGate.ed->tx;
     y = XGate.ed->ty;
     r = XGate.circuit->rot;
