@@ -1,5 +1,5 @@
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Mon Jun 14 10:25:04 2004
+    Last edit by hansen on Thu Sep  2 08:50:46 2004
 ****************************************************************************/
 #include "tkgate.h"
 
@@ -342,6 +342,13 @@ void localization_Setup(Tcl_Interp *tcl)
     logError(ERL_ERROR,"No localized strings for %d messages.  Use 'tkgate -v' for details.",no_msg_count);
   }
 
+  /*
+   * Hack to get right font encoding for Czech.
+   */
+  if (strcmp(msg_lang,"cs") == 0) {
+    extern char *font_encoding;
+    font_encoding = "iso8859-2";
+  }
 
   message_table = H;
 
