@@ -1,6 +1,6 @@
 
 /****************************************************************************
-    Copyright (C) 1987-2004 by Jeffery P. Hansen
+    Copyright (C) 1987-2005 by Jeffery P. Hansen
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    Last edit by hansen on Thu May  6 15:05:20 2004
+    Last edit by hansen on Thu Sep  2 08:48:26 2004
 ****************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
@@ -51,6 +51,8 @@ XGateParams XGate;		/* Parameters used by original gate functions */
 
 static int did_doubleclick = 0;
 
+char *font_encoding = "iso8859-1";
+
 /*
  * Return the code for the current major mode
  */
@@ -316,20 +318,25 @@ void initGCs()
   unsigned mask;
   XGCValues values;
   Pixmap bitPM;
+  char fontName[STRMAX];
 
   /*
      Do font set up
    */
-  XGate.textF   = GrabFont(BODYFONT);
+  sprintf(fontName,BODYFONT,font_encoding);
+  XGate.textF   = GrabFont(fontName);
   XGate.textXF   = Tk_FontId(XGate.textF);
 
-  XGate.textbF  = GrabFont(BOLDBODYFONT);
+  sprintf(fontName,BOLDBODYFONT,font_encoding);
+  XGate.textbF  = GrabFont(fontName);
   XGate.textbXF  = Tk_FontId(XGate.textbF);
 
-  XGate.stextF  = GrabFont(SMALLFONT);
+  sprintf(fontName,SMALLFONT,font_encoding);
+  XGate.stextF  = GrabFont(fontName);
   XGate.stextXF  = Tk_FontId(XGate.stextF);
 
-  XGate.stextbF = GrabFont(BOLDSMALLFONT);
+  sprintf(fontName,BOLDSMALLFONT,font_encoding);
+  XGate.stextbF = GrabFont(fontName);
   XGate.stextbXF = Tk_FontId(XGate.stextbF);
 
 #if TKGATE_JSUPPORT
